%define libmajor	0
%define libname		%mklibname pcre 2 %{libmajor}

%define pcre2posixmajor	3
%define libnameposix	%mklibname pcre2posix %{pcre2posixmajor}

%define develname	%mklibname %{name} -d
%define staticname	%mklibname %{name} -s -d

Name:		pcre2
Version:	10.45
Release:	%mkrel 2
Summary:	Perl-compatible regular expression library
Group:		System/Libraries
# the library:                          BSD
# pcre2test (linked to GNU readline):   BSD (linked to GPLv3+)
#Not distributed in binary package
# autotools:                            GPLv3+ with exception
# install-sh:                           MIT
License:	BSD
URL:		https://www.pcre.org/
Source0:	https://github.com/PCRE2Project/pcre2/releases/download/pcre2-%{version}/%{name}-%{version}.tar.bz2
Source1:	https://github.com/PCRE2Project/pcre2/releases/download/pcre2-%{version}/%{name}-%{version}.tar.bz2.sig
# Do no set RPATH if libdir is not /usr/lib
Patch0:		pcre2-10.10-Fix-multilib.patch
BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	coreutils
BuildRequires:	diffutils
BuildRequires:	gcc
BuildRequires:	libtool
BuildRequires:	make
BuildRequires:	pkgconfig(readline)

%description
PCRE2 is a re-working of the original PCRE (Perl-compatible regular
expression) library to provide an entirely new API.

PCRE2 is written in C, and it has its own API. There are three sets of
functions, one for the 8-bit library, which processes strings of bytes, one
for the 16-bit library, which processes strings of 16-bit values, and one for
the 32-bit library, which processes strings of 32-bit values. There are no C++
wrappers.

The distribution does contain a set of C wrapper functions for the 8-bit
library that are based on the POSIX regular expression API (see the pcre2posix
man page). These can be found in a library called libpcre2posix. Note that
this just provides a POSIX calling interface to PCRE2; the regular expressions
themselves still follow Perl syntax and semantics. The POSIX API is
restricted, and does not give full access to all of PCRE2's facilities.

%package -n	%{libname}
Summary:	Perl-compatible regular expression library
Group:		System/Libraries

%description -n	%{libname}
PCRE2 is a re-working of the original PCRE (Perl-compatible regular
expression) library to provide an entirely new API.

%package -n	%{libnameposix}
Summary:	Perl-compatible regular expression library
Group:		System/Libraries

%description -n	%{libnameposix}
This package contains the shared library libpcre2-posix.

%package -n	%{develname}
Summary:	Development files for %{name}
Group:		Development/C
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libnameposix} = %{version}-%{release}
Requires:	gcc

%description -n	%{develname}
Development files (headers, libraries for dynamic linking, documentation)
for %{name}.  The header file for the POSIX-style functions is called
pcre2posix.h.

%package	tools
Summary:	Auxiliary utilities for %{name}
# pcre2test (linked to GNU readline)	BSD (linked to GPLv3+)
License:	BSD and GPLv3+
Group:		Development/Tools

%description	tools
Utilities demonstrating PCRE2 capabilities like pcre2grep or pcre2test.

%package -n	%{staticname}
Group:		Development/C
Summary:	Library file for linking statically to PCRE2
Provides:	%{name}-static-devel = %{version}-%{release}
Requires:	%{develname} = %{version}-%{release}

%description -n	%{staticname}
Library file for linking statically against PCRE2.

%prep
%autosetup -p1

%build
autoreconf -vfi
%configure \
    --enable-jit \
    --enable-pcre2grep-jit \
    --disable-bsr-anycrlf \
    --disable-coverage \
    --disable-ebcdic \
    --disable-fuzz-support \
    --disable-never-backslash-C \
    --enable-newline-is-lf \
    --enable-pcre2-8 \
    --enable-pcre2-16 \
    --enable-pcre2-32 \
    --enable-pcre2grep-callout \
    --enable-pcre2grep-callout-fork \
    --disable-pcre2grep-libbz2 \
    --disable-pcre2grep-libz \
    --disable-pcre2test-libedit \
    --enable-percent-zt \
    --enable-pcre2test-libreadline \
    --disable-rebuild-chartables \
    --enable-shared \
    --enable-stack-for-recursion \
    --enable-static \
    --enable-unicode \
    --disable-valgrind
%make_build

%install
%make_install

# These are handled by %%doc in %%files
rm -rf %{buildroot}%{_docdir}/pcre2

%check
make check VERBOSE=yes

%files -n %{libname}
%license COPYING LICENCE.md
%doc AUTHORS.md ChangeLog NEWS README
%{_libdir}/libpcre2-[0-9]*.so.%{libmajor}{,.*}

%files -n %{libnameposix}
%license COPYING
%{_libdir}/libpcre2-posix.so.%{pcre2posixmajor}{,.*}

%files -n %{develname}
%doc doc/*.txt doc/html
%doc HACKING ./src/pcre2demo.c
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*.h
%{_mandir}/man1/pcre2-config.*
%{_mandir}/man3/*
%{_bindir}/pcre2-config

%files tools
%{_bindir}/pcre2grep
%{_bindir}/pcre2test
%{_mandir}/man1/pcre2grep.*
%{_mandir}/man1/pcre2test.*

%files -n %{staticname}
%{_libdir}/*.a


%changelog
* Tue Jul 01 2025 umeabot <umeabot> 10.45-2.mga10
+ Revision: 2235682
- Mageia 10 Mass Rebuild

* Thu Feb 06 2025 daviddavid <daviddavid> 10.45-1.mga10
+ Revision: 2145691
- new version: 10.45

* Sat Jun 22 2024 daviddavid <daviddavid> 10.44-1.mga10
+ Revision: 2076134
- new version: 10.44

* Tue Apr 09 2024 wally <wally> 10.43-1.mga10
+ Revision: 2056248
- new version 10.43

* Fri Apr 05 2024 wally <wally> 10.42-2.mga10
+ Revision: 2054674
- basesystem rebuild for i686

* Sat Jan 14 2023 daviddavid <daviddavid> 10.42-1.mga9
+ Revision: 1932800
- new version: 10.42

* Tue Nov 08 2022 tv <tv> 10.40-2.mga9
+ Revision: 1904624
- Add static subpkg for qemu

* Fri May 13 2022 luigiwalser <luigiwalser> 10.40-1.mga9
+ Revision: 1858008
- 10.40

* Thu Mar 24 2022 umeabot <umeabot> 10.39-2.mga9
+ Revision: 1824146
- Mageia 9 Mass Rebuild

* Mon Nov 08 2021 wally <wally> 10.39-1.mga9
+ Revision: 1754767
- new version 10.39

* Fri Jul 30 2021 luigiwalser <luigiwalser> 10.37-1.mga9
+ Revision: 1738243
- pcre2posix major is now 3
- 10.37
- add upstream patch to fix PHP regression (exim#2763, php#81101)

* Sun Dec 20 2020 luigiwalser <luigiwalser> 10.36-1.mga8
+ Revision: 1661849
- 10.36
- remove upstream patches

* Wed Dec 02 2020 luigiwalser <luigiwalser> 10.35-2.mga8
+ Revision: 1651798
- add several upstream bug fixes via fedora

* Thu May 21 2020 luigiwalser <luigiwalser> 10.35-1.mga8
+ Revision: 1586521
- 10.35
- remove upstream patches

* Wed Feb 19 2020 umeabot <umeabot> 10.34-3.mga8
+ Revision: 1542550
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Jan 05 2020 tv <tv> 10.34-2.mga8
+ Revision: 1476622
- rebuild for new readline

* Mon Dec 09 2019 daviddavid <daviddavid> 10.34-1.mga8
+ Revision: 1465406
- new version: 10.34

* Thu Oct 24 2019 mokraemer <mokraemer> 10.33-2.mga8
+ Revision: 1455642
- patch php bug #78272

* Mon May 13 2019 luigiwalser <luigiwalser> 10.33-1.mga7
+ Revision: 1397527
- 10.33
- add upstream patch via fedora to validate number of capturing parentheses

* Wed Sep 12 2018 daviddavid <daviddavid> 10.32-1.mga7
+ Revision: 1258614
- new version: 10.32

* Mon May 28 2018 wally <wally> 10.31-1.mga7
+ Revision: 1232800
- new version 10.31
- new pcre2-posix lib major 2
- drop upstreamed patches

* Tue Jan 02 2018 wally <wally> 10.23-3.mga7
+ Revision: 1189458
- rebuild for new readline

* Tue Apr 25 2017 neoclust <neoclust> 10.23-2.mga6
+ Revision: 1097366
- Add Fedora patches to fix bugs ( including CVE-2017-7186 (mga#20546))

* Thu Feb 16 2017 luigiwalser <luigiwalser> 10.23-1.mga6
+ Revision: 1086377
- 10.23

* Sun Aug 21 2016 wally <wally> 10.22-2.mga6
+ Revision: 1047605
- add pcre2-devel provides to devel pkg

* Wed Aug 10 2016 luigiwalser <luigiwalser> 10.22-1.mga6
+ Revision: 1045327
- 10.22
- remove upstreamed patches
- add libpcre2posix package for pcre2-posix lib

* Fri Jun 10 2016 luigiwalser <luigiwalser> 10.21-3.mga6
+ Revision: 1021014
- add upstream patch to fix race condition in JIT reported by Mozilla

* Sun May 22 2016 luigiwalser <luigiwalser> 10.21-2.mga6
+ Revision: 1017648
- add upstream patch to fix CVE-2016-3191

* Mon Jan 25 2016 luigiwalser <luigiwalser> 10.21-1.mga6
+ Revision: 927218
- use configure2_5x
- 10.21

* Mon Nov 23 2015 ovitters <ovitters> 10.20-3.mga6
+ Revision: 905303
- fix requires

* Mon Nov 23 2015 ovitters <ovitters> 10.20-2.mga6
+ Revision: 905268
- increase release because why not
- fix group
- adapted from fedora

